==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/sql/kotlin/inputs/GetDatabaseSecurityAlertPolicyPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sql.kotlin.inputs

import com.pulumi.azurenative.sql.inputs.GetDatabaseSecurityAlertPolicyPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property databaseName The name of the  database for which the security alert policy is defined.
 * @property resourceGroupName The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
 * @property securityAlertPolicyName The name of the security alert policy.
 * @property serverName The name of the  server.
 */
public data class GetDatabaseSecurityAlertPolicyPlainArgs(
    public val databaseName: String,
    public val resourceGroupName: String,
    public val securityAlertPolicyName: String,
    public val serverName: String,
) : ConvertibleToJava<com.pulumi.azurenative.sql.inputs.GetDatabaseSecurityAlertPolicyPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.sql.inputs.GetDatabaseSecurityAlertPolicyPlainArgs =
        com.pulumi.azurenative.sql.inputs.GetDatabaseSecurityAlertPolicyPlainArgs.builder()
            .databaseName(databaseName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .securityAlertPolicyName(securityAlertPolicyName.let({ args0 -> args0 }))
            .serverName(serverName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetDatabaseSecurityAlertPolicyPlainArgs].
 */
@PulumiTagMarker
public class GetDatabaseSecurityAlertPolicyPlainArgsBuilder internal constructor() {
    private var databaseName: String? = null

    private var resourceGroupName: String? = null

    private var securityAlertPolicyName: String? = null

    private var serverName: String? = null

    /**
     * @param value The name of the  database for which the security alert policy is defined.
     */
    @JvmName("ewspasmljnglmhkp")
    public suspend fun databaseName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.databaseName = mapped
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("rqsepfvabftqhvmh")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the security alert policy.
     */
    @JvmName("gfognhknfmesyswf")
    public suspend fun securityAlertPolicyName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.securityAlertPolicyName = mapped
    }

    /**
     * @param value The name of the  server.
     */
    @JvmName("rqfpfndmfwcgtqip")
    public suspend fun serverName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.serverName = mapped
    }

    internal fun build(): GetDatabaseSecurityAlertPolicyPlainArgs =
        GetDatabaseSecurityAlertPolicyPlainArgs(
            databaseName = databaseName ?: throw PulumiNullFieldException("databaseName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            securityAlertPolicyName = securityAlertPolicyName ?: throw
                PulumiNullFieldException("securityAlertPolicyName"),
            serverName = serverName ?: throw PulumiNullFieldException("serverName"),
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/sql/kotlin/inputs/GetDatabaseSecurityAlertPolicyPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sql.kotlin.inputs

import com.pulumi.azurenative.sql.inputs.GetDatabaseSecurityAlertPolicyPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property databaseName The name of the  database for which the security alert policy is defined.
 * @property resourceGroupName The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
 * @property securityAlertPolicyName The name of the security alert policy.
 * @property serverName The name of the  server.
 */
public data class GetDatabaseSecurityAlertPolicyPlainArgs(
    public val databaseName: String,
    public val resourceGroupName: String,
    public val securityAlertPolicyName: String,
    public val serverName: String,
) : ConvertibleToJava<com.pulumi.azurenative.sql.inputs.GetDatabaseSecurityAlertPolicyPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.sql.inputs.GetDatabaseSecurityAlertPolicyPlainArgs =
        com.pulumi.azurenative.sql.inputs.GetDatabaseSecurityAlertPolicyPlainArgs.builder()
            .databaseName(databaseName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .securityAlertPolicyName(securityAlertPolicyName.let({ args0 -> args0 }))
            .serverName(serverName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetDatabaseSecurityAlertPolicyPlainArgs].
 */
@PulumiTagMarker
public class GetDatabaseSecurityAlertPolicyPlainArgsBuilder internal constructor() {
    private var databaseName: String? = null

    private var resourceGroupName: String? = null

    private var securityAlertPolicyName: String? = null

    private var serverName: String? = null

    /**
     * @param value The name of the  database for which the security alert policy is defined.
     */
    @JvmName("sdarhuuaymjwcuav")
    public suspend fun databaseName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.databaseName = mapped
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("ajbteborljyvsgla")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the security alert policy.
     */
    @JvmName("wpeydwlqqbekqevn")
    public suspend fun securityAlertPolicyName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.securityAlertPolicyName = mapped
    }

    /**
     * @param value The name of the  server.
     */
    @JvmName("uapijjtyibxsesfd")
    public suspend fun serverName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.serverName = mapped
    }

    internal fun build(): GetDatabaseSecurityAlertPolicyPlainArgs =
        GetDatabaseSecurityAlertPolicyPlainArgs(
            databaseName = databaseName ?: throw PulumiNullFieldException("databaseName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            securityAlertPolicyName = securityAlertPolicyName ?: throw
                PulumiNullFieldException("securityAlertPolicyName"),
            serverName = serverName ?: throw PulumiNullFieldException("serverName"),
        )
}
